@@ -37,7 +37,7 @@ use LWP::Protocol::https;
 use Games::Go::AGA::Parse::TDList;
 use Games::Go::AGA::Parse::Util qw( is_Rating );
 
-our $VERSION = '0.026'; # VERSION
+our $VERSION = '0.032'; # VERSION
 
 sub LAST_NAME  { 0 };
 sub FIRST_NAME { 1 };
@@ -490,8 +490,9 @@ sub update_from_AGA {
     open($fh, '<', $fname)
         or croak("Error opening $fname for reading: $!\n");
     $self->update_from_file($fh);
+    close $fh;
 
-    exit if (defined $pid); # exit if this is a spawned child
+    exit if (defined $pid); # exit if this is a spawned child ($pid == 0)
 }
 
 sub update_from_file {
@@ -512,10 +513,12 @@ sub update_from_file {
     my @errors;
     my $ii = 0;
     while (my $line = <$fh>) {
-        print '.' if (++$ii % 1000 == 0);
-        print "\n" if ($ii % 40000 == 0);
+        if ($verbose) {
+            print '.' if (++$ii % 1000 == 0);
+            print "\n" if ($ii % 40000 == 0);
+        }
         try {   # in case a line crashes, print error but continue
-#print "parse $line";
+#print "parse $line" if ($verbose);
             $parser->parse($line);
             my $update = $parser->as_array;
             if ($update->[LAST_NAME] or $update->[FIRST_NAME]) {
@@ -571,7 +574,7 @@ sub update_from_file {
 sub sql_columns {
     my ($self, $joiner) = @_;
 
-    $joiner = ', ' if (@_ < 2);
+    $joiner = ', ' if (not defined $joiner);
     return join($joiner,
         map({ keys %{$_} }
             @columns,
@@ -584,7 +587,7 @@ sub sql_columns {
 sub sql_column_types {
     my ($self, $joiner) = @_;
 
-    $joiner = ', ' if (@_ < 2);
+    $joiner = ', ' if (not defined $joiner);
 
     return join($joiner,
         map({join ' ', each %{$_}}
@@ -599,7 +602,7 @@ sub sql_column_types {
 sub sql_update_qs {
     my ($self, $joiner) = @_;
 
-    $joiner = ', ' if (@_ < 2);
+    $joiner = ', ' if (not defined $joiner);
 
     return join($joiner,
         map({ (keys(%{$_}))[0] . ' = ?' }
@@ -609,12 +612,12 @@ sub sql_update_qs {
     );
 }
 
-# 'column = ?, ' place-holder question marks for each column,
-#    appropriate for a INSERT query
+# place-holder question marks for each column,
+#    appropriate for an INSERT query
 sub sql_insert_qs {
     my ($self, $joiner) = @_;
 
-    $joiner = ', ' if (@_ < 2);
+    $joiner = ', ' if (not defined $joiner);
 
     return join($joiner,
         map({ '?' }     # one question mark per column
@@ -638,7 +641,7 @@ Games::Go::AGA::TDListDB - an SQL object for holding AGA TDList data
 
 =head1 VERSION
 
-version 0.026
+version 0.032
 
 =head1 SYNOPSIS
 
